/*
 * SourceMod Radio
 *
 * Adds a radio player to SourceMod that supports direct station links or streaming audio
 *
 * Coded by dubbeh - www.dubbeh.net
 *
 * Licensed under the GPLv3
 *
 */


public Action Command_Radio(int iClient, int iArgs)
{
	if (!g_cVarEnable.IntValue)
	{
		return Plugin_Handled;
	}

	if (!g_bPlayListFound)
	{
		CReplyToCommand(iClient, "%T", "No Playlist Found", LANG_SERVER);
		return Plugin_Handled;
	}

	if (g_bShownAutoplaySettings[iClient] == false && g_cVarShowAutoPlaySettings.BoolValue) {
		ShowAutoPlaySettingsToClient(iClient);
		return Plugin_Handled;
	}

	if (g_mRadioBaseMenu != null) {
		g_mRadioBaseMenu.Display(iClient, MENU_TIME_FOREVER);
	}
	else {
		SetFailState("[SM-RADIO] Base menu appears to be invalid. Please report this error to the author.");
	}
	
	return Plugin_Handled;
}

public Action Command_Browse(int iClient, int iArgs)
{
	if (!g_cVarEnable.IntValue)
	{
		return Plugin_Handled;
	}

	if (iArgs == 1)
	{
		char szWebsite[MAX_MOTD_URL_SIZE + 1] = "";

		GetCmdArg(1, szWebsite, sizeof(szWebsite));
		BrowseURL(iClient, szWebsite);
	}
	else
	{
		CReplyToCommand(iClient, "%T", "Invalid Browse Format", LANG_SERVER);
		CReplyToCommand(iClient, "%T", "Browse Usage", LANG_SERVER);
	}
	
	return Plugin_Handled;
}

public Action Command_RadioOff(int iClient, int iArgs)
{
	if (g_cVarEnable.IntValue)
	{
		LoadOffPage(iClient);
		CReplyToCommand(iClient, "%T", "Radio Turned Off", LANG_SERVER);
	}
	
	return Plugin_Handled;
}

public Action Command_Volume(int iClient, int iArgs)
{
	if (!g_cVarEnable.IntValue)
	{
		return Plugin_Handled;
	}

	if (!g_bPlayListFound)
	{
		CReplyToCommand(iClient, "%T", "No Playlist Found", LANG_SERVER);
		return Plugin_Handled;
	}
	
	if (iArgs > 0)
	{
		char szStationVolume[32] = "";
		float fVolume = 0.1;

		GetCmdArg(1, szStationVolume, sizeof(szStationVolume));
		fVolume = StringToFloat(szStationVolume);
			
		if (fVolume > 0.01 && fVolume < 1.0)
		{
			g_Cookies.SetVolume(iClient, szStationVolume);
			CReplyToCommand(iClient, "%T", "Volume Set To", LANG_SERVER, szStationVolume);
			LoadStationFromCookie(iClient);
		}
		else
		{
				CPrintToChat(iClient, "%T", "Invalid Volume Setting", LANG_SERVER);
		}
	}
	else if (g_mRadioVolumeMenu != INVALID_HANDLE)
	{
		g_mRadioVolumeMenu.Display(iClient, MENU_TIME_FOREVER);
	}
	else
	{
		RLogMessage("[SM-RADIO] Volume menu handle appears to be invalid. Please report this error the author.");
	}
	
	return Plugin_Handled;
}

public Action Command_Track(int iClient, int iArgs)
{
	if (!g_cVarEnable.IntValue)
	{
		return Plugin_Handled;
	}

	if (!g_bPlayListFound)
	{
		CReplyToCommand(iClient, "%T", "No Playlist Found", LANG_SERVER);
		return Plugin_Handled;
	}
		
	if (g_cVarEnableTrackQuery.IntValue)
	{
		if (STEAMWORKS_AVAILABLE() && SteamWorks_IsLoaded())
			GetCurretTrack(iClient);
		else
			CReplyToCommand(iClient, "%T", "Missing SteamWorks", LANG_SERVER);
	}
	else
	{
		CReplyToCommand(iClient, "%T", "Track Query Disabled", LANG_SERVER);
	}
	
	return Plugin_Handled;
}

public Action Command_Genres(int iClient, int iArgs)
{
	if (!g_cVarEnable.IntValue || !g_bUseGenres)
	{
		return Plugin_Handled;
	}

	if (!g_bPlayListFound)
	{
		CReplyToCommand(iClient, "%T", "No Playlist Found", LANG_SERVER);
		return Plugin_Handled;
	}

	if (iArgs == 0)
	{
		if (g_mRadioBaseGenresMenu != INVALID_HANDLE)
		{
			g_mRadioBaseGenresMenu.Display(iClient, MENU_TIME_FOREVER);
		}
		else
		{
			SetFailState("[SM-RADIO] Genre menu appears to be invalid. Please report this error to the author.");
		}
	}
	else if (iArgs > 0)
	{
		char szBaseSubCommand[64] = "";
		int iGenreFound = 0;
		char szGenreName[64] = "";

		GetCmdArg(1, szBaseSubCommand, sizeof(szBaseSubCommand));
		iGenreFound = g_Genres.FindPrimaryGenreByName(szBaseSubCommand);
			
		if (g_Genres.IsValid(iGenreFound))
		{
			if (g_Genres.GetMenuHandle(iGenreFound) != INVALID_HANDLE)
			{
				DisplayMenu(g_Genres.GetMenuHandle(iGenreFound), iClient, MENU_TIME_FOREVER);
			}
			else
			{
				g_Genres.GetName(iGenreFound, szGenreName, sizeof(szGenreName));
				SetFailState("[SM-RADIO] Genre \"%s\" using index \"%d\" appears to be invalid. Please report this error to the author.", szGenreName, g_Genres.GetID(iGenreFound));
			}
		}
		else
		{
			CReplyToCommand(iClient, "%T :", "Listing Primary Genres", LANG_SERVER);
			PrintPrimaryGenreList(iClient);
		}
	}
	
	return Plugin_Handled;
}

public Action Command_Help(int iClient, int iArgs)
{
	char szBuffer[128] = "";
	
	if (iClient == 0)
		return Plugin_Handled;
	
	Panel panel = CreatePanel();
	
	Format(szBuffer, sizeof(szBuffer), "SourceMod Radio v%s - www.dubbeh.net", PLUGIN_VERSION);
	panel.SetTitle(szBuffer);
	
	Format(szBuffer, sizeof(szBuffer), "%T", "Radio Command Info", LANG_SERVER);
	panel.DrawItem(szBuffer);
	Format(szBuffer, sizeof(szBuffer), "%T", "Browse Command Info", LANG_SERVER);
	panel.DrawItem(szBuffer);
	Format(szBuffer, sizeof(szBuffer), "%T", "Genre Command Info", LANG_SERVER);
	panel.DrawItem(szBuffer);
	Format(szBuffer, sizeof(szBuffer), "%T", "Volume Command Info", LANG_SERVER);
	panel.DrawItem(szBuffer);
	Format(szBuffer, sizeof(szBuffer), "%T", "Track Command Info", LANG_SERVER);
	panel.DrawItem(szBuffer);
	Format(szBuffer, sizeof(szBuffer), "%T", "Radio Off Command Info", LANG_SERVER);
	panel.DrawItem(szBuffer);
	
	panel.Send(iClient, Handler_PanelHelp, 0);
	delete panel;
	
	return Plugin_Handled;
}

public int Handler_PanelHelp(Menu mMenu, MenuAction maAction, int iClient, int iParam)
{
	if (maAction == MenuAction_End)
	{
		delete mMenu;
	}

	return 0;
}

public Action Command_ForcePlaylistDownload(int iClient, int iArgs)
{
	if (g_cVarEnable.IntValue)
	{
		InitPlaylistDownload(iClient);
	}
	
	return Plugin_Handled;
}
