/*
 * SourceMod Radio
 *
 * Adds a radio player to SourceMod that supports direct station links or streaming audio
 *
 * Coded by dubbeh - www.dubbeh.net
 *
 * Licensed under the GPLv3
 *
 */

ArrayList g_alStationIDs = null;
ArrayList g_alStationGenreIDs = null;
ArrayList g_alStationNames = null;
ArrayList g_alStationStreamURLs = null;
ArrayList g_alStationCurrentTracks = null;
ArrayList g_alStationLastUpdateTimes = null;

ArrayList g_alCustomStationIDs = null;
ArrayList g_alCustomStationGenreIDs = null;
ArrayList g_alCustomStationNames = null;
ArrayList g_alCustomStationStreamURLs = null;
ArrayList g_alCustomStationCurrentTracks = null;
ArrayList g_alCustomStationLastUpdateTimes = null;

methodmap Stations
{
	property int iCount
	{
		public get()
		{
			return g_alStationIDs.Length;
		}
	}
	
	public bool Init()
	{
		g_alStationIDs = CreateArray(8, 0);
		g_alStationGenreIDs = CreateArray(8, 0);
		g_alStationNames = CreateArray(128, 0);
		g_alStationStreamURLs = CreateArray(192, 0);
		g_alStationCurrentTracks = CreateArray(64, 0);
		g_alStationLastUpdateTimes = CreateArray(8, 0);
		
		if (g_alStationIDs == null ||
			g_alStationGenreIDs == null ||
			g_alStationNames == null ||
			g_alStationStreamURLs == null ||
			g_alStationCurrentTracks == null ||
			g_alStationLastUpdateTimes == null)
			return false;
		else
		    return true;
	}

	public bool Clear()
	{
		delete g_alStationIDs;
		delete g_alStationGenreIDs;
		delete g_alStationNames;
		delete g_alStationStreamURLs;
		delete g_alStationCurrentTracks;
		delete g_alStationLastUpdateTimes;
	}

	public void AddEntry(int iStationID, int iGenreID, char[] szStationName, char[] szStreamURL = "about:blank", char[] szCurrentTrack = "Unknown", int iLastUpdateTime = 0)
	{
		g_alStationIDs.Push(iStationID);
		g_alStationGenreIDs.Push(iGenreID);
		g_alStationNames.PushString(szStationName);
		g_alStationStreamURLs.PushString(szStreamURL);
		g_alStationCurrentTracks.PushString(szCurrentTrack);
		g_alStationLastUpdateTimes.Push(iLastUpdateTime);
	}

	public int GetID(int iStationIndex)
	{
		return g_alStationIDs.Get(iStationIndex);
	}

	public void SetID(int iStationIndex, int iID)
	{
		g_alStationIDs.Set(iStationIndex, iID);
	}

	public int GetGenreID(int iStationIndex)
	{
		return g_alStationGenreIDs.Get(iStationIndex);
	}

	public void SetGenreID(int iStationIndex, int iGenreID)
	{
		g_alStationGenreIDs.Set(iStationIndex, iGenreID);
	}

	public void GetName(int iStationIndex, char[] szBuffer, int iLength)
	{
		g_alStationNames.GetString(iStationIndex, szBuffer, iLength);
	}

	public void SetName(int iStationIndex, const char[] szBuffer)
	{
		g_alStationNames.SetString(iStationIndex, szBuffer);
	}

	public void GetStreamURL(int iStationIndex, char[] szBuffer, int iLength)
	{
		g_alStationStreamURLs.GetString(iStationIndex, szBuffer, iLength);
	}

	public void SetStreamURL(int iStationIndex, const char[] szBuffer)
	{
		g_alStationStreamURLs.SetString(iStationIndex, szBuffer);
	}

	public void GetCurrentTrack(int iStationIndex, char[] szBuffer, int iLength)
	{
		g_alStationCurrentTracks.GetString(iStationIndex, szBuffer, iLength);
	}

	public void SetCurrentTrack(int iStationIndex, const char[] szBuffer)
	{
		g_alStationCurrentTracks.SetString(iStationIndex, szBuffer);
	}

	public int GetLastUpdateTime(int iStationIndex)
	{
		return g_alStationLastUpdateTimes.Get(iStationIndex);
	}

	public void SetLastUpdateTime(int iStationIndex, int iLastUpdateTime)
	{
		g_alStationLastUpdateTimes.Set(iStationIndex, iLastUpdateTime);
	}
	
	public bool IsValid(int iStationIndex)
	{
		if ((iStationIndex < this.iCount) && (iStationIndex != -1))
		    return true;
		else
		    return false;
	}
	
	public int GetIndexFromID(int iID)
	{
		int iSize = this.iCount;
		
		for (int iIndex = 0; iIndex < iSize; iIndex++)
		{
			if (this.GetID(iIndex) == iID)
				return iIndex;
		}
		
		return -1;
	}
}

methodmap CustomStations
{
	property int iCount
	{
		public get()
		{
			return g_alCustomStationIDs.Length;
		}
	}
	
	public bool Init()
	{
		g_alCustomStationIDs = CreateArray(8, 0);
		g_alCustomStationGenreIDs = CreateArray(8, 0);
		g_alCustomStationNames = CreateArray(128, 0);
		g_alCustomStationStreamURLs = CreateArray(192, 0);
		g_alCustomStationCurrentTracks = CreateArray(64, 0);
		g_alCustomStationLastUpdateTimes = CreateArray(8, 0);
		
		if (g_alCustomStationIDs == null ||
			g_alCustomStationGenreIDs == null ||
			g_alCustomStationNames == null ||
			g_alCustomStationStreamURLs == null ||
			g_alCustomStationCurrentTracks == null ||
			g_alCustomStationLastUpdateTimes == null)
			return false;
		else
		    return true;
	}

	public bool Clear()
	{
		delete g_alCustomStationIDs;
		delete g_alCustomStationGenreIDs;
		delete g_alCustomStationNames;
		delete g_alCustomStationStreamURLs;
		delete g_alCustomStationCurrentTracks;
		delete g_alCustomStationLastUpdateTimes;
	}

	public void AddEntry(int iStationID, int iGenreID, char[] szStationName, char[] szStreamURL = "", char[] szCurrentTrack = "", int iLastUpdateTime = 0)
	{
		g_alCustomStationIDs.Push(iStationID);
		g_alCustomStationGenreIDs.Push(iGenreID);
		g_alCustomStationNames.PushString(szStationName);
		g_alCustomStationStreamURLs.PushString(szStreamURL);
		g_alCustomStationCurrentTracks.PushString(szCurrentTrack);
		g_alCustomStationLastUpdateTimes.Push(iLastUpdateTime);
	}

	public int GetID(int iStationIndex)
	{
		return g_alCustomStationIDs.Get(iStationIndex);
	}

	public void SetID(int iStationIndex, int iID)
	{
		g_alCustomStationIDs.Set(iStationIndex, iID);
	}

	public int GetGenreID(int iStationIndex)
	{
		return g_alCustomStationGenreIDs.Get(iStationIndex);
	}

	public void SetGenreID(int iStationIndex, int iGenreID)
	{
		g_alCustomStationGenreIDs.Set(iStationIndex, iGenreID);
	}

	public void GetName(int iStationIndex, char[] szBuffer, int iLength)
	{
		g_alCustomStationNames.GetString(iStationIndex, szBuffer, iLength);
	}

	public void SetName(int iStationIndex, const char[] szBuffer)
	{
		g_alCustomStationNames.SetString(iStationIndex, szBuffer);
	}

	public void GetStreamURL(int iStationIndex, char[] szBuffer, int iLength)
	{
		g_alCustomStationStreamURLs.GetString(iStationIndex, szBuffer, iLength);
	}

	public void SetStreamURL(int iStationIndex, const char[] szBuffer)
	{
		g_alCustomStationStreamURLs.SetString(iStationIndex, szBuffer);
	}

	public void GetCurrentTrack(int iStationIndex, char[] szBuffer, int iLength)
	{
		g_alCustomStationCurrentTracks.GetString(iStationIndex, szBuffer, iLength);
	}

	public void SetCurrentTrack(int iStationIndex, const char[] szBuffer)
	{
		g_alCustomStationCurrentTracks.SetString(iStationIndex, szBuffer);
	}

	public int GetLastUpdateTime(int iStationIndex)
	{
		return g_alCustomStationLastUpdateTimes.Get(iStationIndex);
	}

	public void SetLastUpdateTime(int iStationIndex, int iLastUpdateTime)
	{
		g_alCustomStationLastUpdateTimes.Set(iStationIndex, iLastUpdateTime);
	}
	
	public bool IsValid(int iStationIndex)
	{
		if ((iStationIndex < this.iCount) && (iStationIndex != -1))
		    return true;
		else
		    return false;
	}
	
	public int GetIndexFromID(int iID)
	{
		int iSize = this.iCount;
		
		for (int iIndex = 0; iIndex < iSize; iIndex++)
		{
			if (this.GetID(iIndex) == iID)
				return iIndex;
		}
		
		return -1;
	}
}
